@@ -1,6 +1,6 @@
 # Tests:
-#   trystmt ::= SETUP_EXCEPT suite_stmts_opt POP_BLOCK
-#               try_middle COME_FROM
+#   try_except ::= SETUP_EXCEPT suite_stmts_opt POP_BLOCK
+#                  except_handler COME_FROM
 #   except_stmt ::= except
 
 try:
@@ -9,8 +9,8 @@ except:
     pass
 
 # Tests:
-#   trystmt ::= SETUP_EXCEPT suite_stmts_opt POP_BLOCK
-#               try_middle COME_FROM
+#   try_except ::= SETUP_EXCEPT suite_stmts_opt POP_BLOCK
+#                  except_handler COME_FROM
 #   except_stmt ::= except_cond1 except_suite
 #   except_suite ::= ...
 
@@ -25,3 +25,8 @@ except ImportError:
     x = 3
 finally:
     x = 4
+
+try:
+    x = 1
+except ImportError as e:
+    x = 2
